Class: Sass::Tree::Visitors::Cssize::Extend

Inherits:
Struct
  • Object
show all
Defined in:
lib/sass/tree/visitors/cssize.rb

Overview

A simple struct wrapping up information about a single @extend instance. A single ExtendNode can have multiple Extends if either the parent node or the extended selector is a comma sequence.

Instance Attribute Summary collapse

Instance Attribute Details

#directives ⇒ Array<Sass::Tree::DirectiveNode> (protected)

The directives containing the @extend.

Returns:



111
112
113
# File 'lib/sass/tree/visitors/cssize.rb', line 111

def directives
  @directives
end

#extender ⇒ Sass::Selector::Sequence (protected)

The selector of the CSS rule containing the @extend.

Returns:



111
112
113
# File 'lib/sass/tree/visitors/cssize.rb', line 111

def extender
  @extender
end

#node ⇒ Sass::Tree::ExtendNode (protected)

The node that produced this extend.

Returns:



111
112
113
# File 'lib/sass/tree/visitors/cssize.rb', line 111

def node
  @node
end

#success ⇒ Boolean (protected)

Whether this extend successfully matched a selector.

Returns:

  • (Boolean) —

    the current value of success



111
112
113
# File 'lib/sass/tree/visitors/cssize.rb', line 111

def success
  @success
end

#target ⇒ Array<Sass::Selector::Simple> (protected)

The selector being @extended.

Returns:



111
112
113
# File 'lib/sass/tree/visitors/cssize.rb', line 111

def target
  @target
end